%bcond_with bootstrap

%if %{with bootstrap}
%bcond_with maven_resolver_extra_modules
%else
%bcond_without maven_resolver_extra_modules
%endif

Summary:        Apache Maven Artifact Resolver library
Name:           maven-resolver
Version:        1.7.3
Release:        5%{?dist}
License:        ASL 2.0
URL:            https://maven.apache.org/resolver/
Source0:        https://archive.apache.org/dist/maven/resolver/%{name}-%{version}-source-release.zip
Patch3000:      0001-Remove-use-of-deprecated-SHA-1-and-MD5-algorithms.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap-openjdk8
%else
BuildRequires:  maven-local-openjdk8
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires:  mvn(org.apache.maven.wagon:wagon-provider-api)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.codehaus.plexus:plexus-classworlds)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.inject)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest-core)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-simple)
BuildRequires:  mvn(org.sonatype.sisu:sisu-guice::no_aop:)
%endif
%if %{with maven_resolver_extra_modules}
BuildRequires:  mvn(javax.servlet:javax.servlet-api)
BuildRequires:  mvn(org.eclipse.jetty:jetty-http)
BuildRequires:  mvn(org.eclipse.jetty:jetty-server)
BuildRequires:  mvn(org.eclipse.jetty:jetty-util)
%endif

BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

Provides:       maven-resolver-api = %{version}-%{release}
Provides:       maven-resolver-spi = %{version}-%{release}
Provides:       maven-resolver-impl = %{version}-%{release}
Provides:       maven-resolver-util = %{version}-%{release}
Provides:       maven-resolver-connector-basic = %{version}-%{release}
Provides:       maven-resolver-transport-wagon = %{version}-%{release}
Provides:       maven-resolver-transport-http = %{version}-%{release}
Provides:       maven-resolver-transport-file = %{version}-%{release}
Provides:       maven-resolver-transport-classpath = %{version}-%{release}

%description
Apache Maven Artifact Resolver is a library for working with artifact
repositories and dependency resolution. Maven Artifact Resolver deals with the
specification of local repository, remote repository, developer workspaces,
artifact transports and artifact resolution.

%{?javadoc_package}



%prep
%autosetup -p1

rm maven-resolver-transport-http/src/test/java/org/eclipse/aether/transport/http/HttpTransporterTest.java

%pom_remove_plugin -r :bnd-maven-plugin
%pom_remove_plugin -r org.codehaus.mojo:animal-sniffer-maven-plugin
%pom_remove_plugin -r org.apache.maven.plugins:maven-enforcer-plugin

%pom_disable_module maven-resolver-demos
%pom_disable_module maven-resolver-named-locks-hazelcast
%pom_disable_module maven-resolver-named-locks-redisson
%pom_disable_module maven-resolver-transport-classpath
%if %{without maven_resolver_extra_modules}
%pom_disable_module maven-resolver-transport-file
%pom_disable_module maven-resolver-transport-http
%endif
%mvn_package :maven-resolver-test-util __noinstall

for pom in $(find -mindepth 2 -name pom.xml) ; do
  %pom_add_plugin "org.apache.felix:maven-bundle-plugin" $pom \
  "<configuration>
    <instructions>
      <Bundle-SymbolicName>\${project.groupId}$(sed 's:./maven-resolver::;s:/pom.xml::;s:-:.:g' <<< $pom)</Bundle-SymbolicName>
      <Export-Package>!org.eclipse.aether.internal*,org.eclipse.aether*</Export-Package>
      <_nouses>true</_nouses>
    </instructions>
  </configuration>
  <executions>
    <execution>
      <id>create-manifest</id>
      <phase>process-classes</phase>
      <goals><goal>manifest</goal></goals>
    </execution>
  </executions>"
done
%pom_add_plugin "org.apache.maven.plugins:maven-jar-plugin" pom.xml \
"<configuration>
  <archive>
    <manifestFile>\${project.build.outputDirectory}/META-INF/MANIFEST.MF</manifestFile>
  </archive>
</configuration>"

%mvn_alias 'org.apache.maven.resolver:maven-resolver{*}' 'org.eclipse.aether:aether@1'
%mvn_alias 'org.apache.maven.resolver:maven-resolver-transport-wagon' 'org.eclipse.aether:aether-connector-wagon'
%mvn_file ':maven-resolver{*}' %{name}/maven-resolver@1 aether/aether@1



%build
%mvn_build



%install
%mvn_install



%files -f .mfiles
%license LICENSE NOTICE



%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-4
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.7.3-3
- switched to non-bootstrap building

* Wed Apr 12 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.7.3-2
- rebuilding

* Wed Apr 12 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.7.3-1
- initial
